plot - Plot, various specialized plotting functions and associated utilities — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# plot - Plot, various specialized plotting functions and associated utilities

plot: SpacePy specialized plotting routines

This package provides classes to plot various types of space physics data.

Authors: Brian Larsen and Steve Morley Institution: Los Alamos National Laboratory Contact: balarsen@lanl.gov

Copyright 2011 Los Alamos National Security, LLC.

`spectrogram` | Create and plot generic ‘spectrograms’ for space science.
`utils` | Utility routines for plotting and related activities

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »